@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+#
 #  Copyright 2010 Adam Zapletal
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +14,42 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from docutils import core, io
+from docutils import core, nodes
+from docutils.parsers.rst import directives, Directive
+
+from pygments import highlight
+from pygments.formatters import HtmlFormatter
+from pygments.lexers import get_lexer_by_name, TextLexer
+
+
+DEFAULT = HtmlFormatter(noclasses=False)
+VARIANTS = {}
+
+
+class Pygments(Directive):
+    """ Source code syntax hightlighting for ReST syntax."""
+    required_arguments = 1
+    optional_arguments = 0
+    final_argument_whitespace = True
+    option_spec = dict([(key, directives.flag) for key in VARIANTS])
+    has_content = True
+
+    def run(self):
+        self.assert_has_content()
+        try:
+            lexer = get_lexer_by_name(self.arguments[0])
+        except ValueError:
+            # no lexer found - use the text one instead of an exception
+            lexer = TextLexer()
+        # take an arbitrary option if more than one is given
+        formatter = (self.options and VARIANTS[self.options.keys()[0]]
+                     or DEFAULT)
+        parsed = highlight(u'\n'.join(self.content), lexer, formatter)
+        return [nodes.raw('', parsed, format='html')]
+
+
+directives.register_directive('sourcecode', Pygments)
+directives.register_directive('code-block', Pygments)
 
 
 def html_parts(input_string, source_path=None, destination_path=None,
